@@ -1,12 +1,8 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /*
- * Read value from GPIO line.
+ * This file is part of libgpiod.
  *
- * Copyright (C) 2017 Bartosz Golaszewski <bartekgola@gmail.com>
- *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or (at
- * your option) any later version.
+ * Copyright (C) 2017-2018 Bartosz Golaszewski <bartekgola@gmail.com>
  */
 
 #include <gpiod.h>
@@ -21,7 +17,7 @@ static const struct option longopts[] = {
 	{ "help",	no_argument,	NULL,	'h' },
 	{ "version",	no_argument,	NULL,	'v' },
 	{ "active-low",	no_argument,	NULL,	'l' },
-	{ 0 },
+	{ GETOPT_NULL_LONGOPT },
 };
 
 static const char *const shortopts = "+hvl";
@@ -44,8 +40,6 @@ int main(int argc, char **argv)
 	bool active_low = false;
 	char *device, *end;
 
-	set_progname(argv[0]);
-
 	for (;;) {
 		optc = getopt_long(argc, argv, shortopts, longopts, &opti);
 		if (optc < 0)
@@ -91,9 +85,9 @@ int main(int argc, char **argv)
 			die("invalid GPIO offset: %s", argv[i + 1]);
 	}
 
-	status = gpiod_simple_get_value_multiple("gpioget", device,
-						 offsets, values,
-						 num_lines, active_low);
+	status = gpiod_ctxless_get_value_multiple(device, offsets, values,
+						  num_lines, active_low,
+						  "gpioget");
 	if (status < 0)
 		die_perror("error reading GPIO values");
 
